package com.ruoyi.web.controller.business;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.InterestsTable;
import com.ruoyi.system.service.IInterestsTableService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 商户权益记录Controller
 * 
 * @author ruoyi
 * @date 2022-07-08
 */
@RestController
@RequestMapping("/system/table")
public class InterestsTableController extends BaseController
{
    @Autowired
    private IInterestsTableService interestsTableService;

    /**
     * 查询商户权益记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:table:list')")
    @GetMapping("/list")
    public TableDataInfo list(InterestsTable interestsTable)
    {
        List<InterestsTable> list = interestsTableService.selectInterestsTableList(interestsTable);
        return getDataTable(list);
    }

    /**
     * 导出商户权益记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:table:export')")
    @Log(title = "商户权益记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, InterestsTable interestsTable)
    {
        List<InterestsTable> list = interestsTableService.selectInterestsTableList(interestsTable);
        ExcelUtil<InterestsTable> util = new ExcelUtil<InterestsTable>(InterestsTable.class);
        util.exportExcel(response, list, "商户权益记录数据");
    }

    /**
     * 获取商户权益记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:table:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(interestsTableService.selectInterestsTableById(id));
    }

    /**
     * 新增商户权益记录
     */
    @PreAuthorize("@ss.hasPermi('system:table:add')")
    @Log(title = "商户权益记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody InterestsTable interestsTable)
    {
        return interestsTableService.insertInterestsTable(interestsTable);
    }

    /**
     * 修改商户权益记录
     */
    @PreAuthorize("@ss.hasPermi('system:table:edit')")
    @Log(title = "商户权益记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody InterestsTable interestsTable)
    {
        return interestsTableService.updateInterestsTable(interestsTable);
    }

    /**
     * 删除商户权益记录
     */
    @PreAuthorize("@ss.hasPermi('system:table:remove')")
    @Log(title = "商户权益记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(interestsTableService.deleteInterestsTableByIds(ids));
    }
}
